<?php
	// If this file is called directly, abort.
	if ( ! defined( 'WPINC' ) ) {
		die;
	}

	/**
	 * The public-facing functionality of the plugin.
	 *
	 * @link       https://codeboxr.com
	 * @since      1.0.0
	 *
	 * @package    CBCurrencyConverter
	 * @subpackage CBCurrencyConverter/public
	 */

	/**
	 * The public-facing functionality of the plugin.
	 *
	 * Defines the plugin name, version, and two examples hooks for how to
	 * enqueue the admin-specific stylesheet and JavaScript.
	 *
	 * @package    CBCurrencyConverter
	 * @subpackage CBCurrencyConverter/public
	 * @author     codeboxr <info@codeboxr.com>
	 */
	class CBCurrencyConverter_Public {

		/**
		 * The ID of this plugin.
		 *
		 * @since    1.0.0
		 * @access   private
		 * @var      string $plugin_name The ID of this plugin.
		 */
		private $plugin_name;

		/**
		 * The version of this plugin.
		 *
		 * @since    1.0.0
		 * @access   private
		 * @var      string $version The current version of this plugin.
		 */
		private $version;

		/**
		 * Initialize the class and set its properties.
		 *
		 * @param string $plugin_name The name of the plugin.
		 * @param string $version     The version of this plugin.
		 *
		 * @since    1.0.0
		 *
		 */
		public function __construct( $plugin_name, $version ) {

			$this->plugin_name = $plugin_name;
			$this->version     = $version;

			$this->settings_api = new CBCurrencyconverterSetting();
		}//end of contructor

		public function cbcurrencyconverter_init() {
			do_action( 'cbcurrencyconverter_public', $this );
		}//end cbcurrencyconverter_init

		public function init_shortcodes() {
			add_shortcode( 'cbcurrencyconverter', array( $this, 'cbcurrencyconverter_shortcode' ) );
		}

		/**
		 * Register the stylesheets for the public-facing side of the site.
		 *
		 * @since    1.0.0
		 */
		public function enqueue_styles() {
			wp_register_style( 'select2',
				plugin_dir_url( __FILE__ ) . '../assets/js/select2/css/select2.min.css',
				array(),
				$this->version );
			wp_register_style( 'cbcurrencyconverter-public', plugin_dir_url( __FILE__ ) . '../assets/css/cbcurrencyconverter-public.css', array( 'select2' ), $this->version, 'all' );

			wp_enqueue_style( 'select2' );
			wp_enqueue_style( 'cbcurrencyconverter-public' );
		}//end enqueue_styles

		/**
		 * Register the JavaScript for the public-facing side of the site.
		 *
		 * @since    1.0.0
		 */
		public function enqueue_scripts() {
			$ajax_nonce = wp_create_nonce( "cbcurrencyconverter_nonce" );

			wp_register_script( 'select2', plugin_dir_url( __FILE__ ) . '../assets/js/select2/js/select2.min.js', array( 'jquery' ), $this->version, true );

			wp_register_script( 'cbcurrencyconverter-public',
				plugin_dir_url( __FILE__ ) . '../assets/js/cbcurrencyconverter-public.js',
				array(
					'jquery',
					'select2',
				),
				$this->version,
				true );

			wp_localize_script( 'cbcurrencyconverter-public',
				'cbcurrencyconverter',
				array(
					'ajaxurl'         => admin_url( 'admin-ajax.php' ),
					'nonce'           => $ajax_nonce,
					'empty_selection' => esc_html__( 'Please choose from or to currency properly', 'cbcurrencyconverter' ),
					'same_selection'  => esc_html__( 'From and to currency both are same!', 'cbcurrencyconverter' ),
					'please_select'   => esc_html__( 'Please Select', 'cbcurrencyconverter' ),
				) );

			wp_enqueue_script( 'jquery' );
			wp_enqueue_script( 'select2' );
			wp_enqueue_script( 'cbcurrencyconverter-public' );
		}//end emthod enqueue_scripts


		/**
		 * Shortcode handler
		 *
		 * @return string
		 */
		public function cbcurrencyconverter_shortcode( $atts ) {


			$global_settings     = get_option( 'cbcurrencyconverter_global_settings' );
			$list_settings       = get_option( 'cbcurrencyconverter_list_settings' );
			$calculator_settings = get_option( 'cbcurrencyconverter_calculator_settings' );


			//general setting
			$layout       = ( isset( $global_settings['cbcurrencyconverter_defaultlayout'] ) ) ? $global_settings['cbcurrencyconverter_defaultlayout'] : 'cal';
			$decimalpoint = ( isset( $global_settings['cbcurrencyconverter_decimalpoint'] ) ) ? $global_settings['cbcurrencyconverter_decimalpoint'] : 2;


			//list setting
			$list_title          = ( isset( $list_settings['cbcurrencyconverter_title_list'] ) ) ? $list_settings['cbcurrencyconverter_title_list'] : esc_html__( 'List of Currency', 'cbcurrencyconverter' ); //list title
			$list_from_currency  = ( isset( $list_settings['cbcurrencyconverter_defaultcurrency_list'] ) ) ? $list_settings['cbcurrencyconverter_defaultcurrency_list'] : 'USD'; //we need to set something as default currency to make the list work
			$list_to_currency    = ( isset( $list_settings['cbcurrencyconverter_tocurrency_list'] ) ) ? $list_settings['cbcurrencyconverter_tocurrency_list'] : array(
				'GBP',
				'CAD',
				'AUD',
			); //list of currency
			$list_default_amount = ( isset( $list_settings['cbcurrencyconverter_defaultamount_forlist'] ) ) ? $list_settings['cbcurrencyconverter_defaultamount_forlist'] : 1; //default amount


			//calculator setting
			$calc_title          = ( isset( $calculator_settings['cbcurrencyconverter_title_cal'] ) ) ? $calculator_settings['cbcurrencyconverter_title_cal'] : esc_html__( 'Currency Calculator', 'cbcurrencyconverter' );
			$calc_from_currency  = ( isset( $calculator_settings['cbcurrencyconverter_fromcurrency'] ) ) ? $calculator_settings['cbcurrencyconverter_fromcurrency'] : 'USD';
			$calc_to_currency    = ( isset( $calculator_settings['cbcurrencyconverter_tocurrency'] ) ) ? $calculator_settings['cbcurrencyconverter_tocurrency'] : 'CAD';
			$calc_default_amount = ( isset( $calculator_settings['cbcurrencyconverter_defaultamount_for_calculator'] ) ) ? $calculator_settings['cbcurrencyconverter_defaultamount_for_calculator'] : 1;

			$calc_currencies = ( isset( $calculator_settings['cbcurrencyconverter_enabledcurrencies_calculator'] ) ) ? $calculator_settings['cbcurrencyconverter_enabledcurrencies_calculator'] : array(
				'USD',
				'GBP',
				'CAD',
				'AUD',
			);


			if(is_array($calc_currencies)){
				$calc_currencies = implode( ',', $calc_currencies );
			}

			if(is_array($list_to_currency)){
				$list_to_currency = implode( ',', $list_to_currency );
			}

			$instance = shortcode_atts( array(
				'layout'              => $layout,//cal, list, calwithlisttop, calwithlistbottom
				'decimalpoint'        => $decimalpoint, //this is common for cal and list both
				'calc_currencies'     => $calc_currencies,//list of currency, comma separated user input, example USD,GBP
				'calc_title'          => $calc_title,//string
				'calc_from_currency'  => $calc_from_currency,
				'calc_to_currency'    => $calc_to_currency,
				'calc_default_amount' => $calc_default_amount,//numeric value
				'list_title'          => $list_title,// string
				'list_from_currency'  => $list_from_currency,
				'list_to_currency'    => $list_to_currency,//comma separated, example  GBP,BDT
				'list_default_amount' => $list_default_amount,//numeric value

			), $atts, 'cbcurrencyconverter' );


			if(is_string($instance['calc_currencies'])){
				$instance['calc_currencies']  = explode( ',', $instance['calc_currencies'] );
			}

			if(is_string($instance['list_to_currency'])){
				$instance['list_to_currency'] = explode( ',', $instance['list_to_currency'] );
			}


			extract( $instance );

			if ( $layout == 'list' ) {
				return CBCurrencyConverterHelper::cbxcclistview( 'shortcode', $instance );
			} elseif ( $layout == 'cal' ) {
				return CBCurrencyConverterHelper::cbxcccalcview( 'shortcode', $instance );
			} elseif ( $layout == 'calwithlistbottom' ) {
				return CBCurrencyConverterHelper::cbxcccalcview( 'shortcode', $instance ) . CBCurrencyConverterHelper::cbxcclistview( 'shortcode', $instance );
			} elseif ( $layout == 'calwithlisttop' ) {
				return CBCurrencyConverterHelper::cbxcclistview( 'shortcode', $instance ) . CBCurrencyConverterHelper::cbxcccalcview( 'shortcode', $instance );
			}

		}//end codeboxrcurrencyconverter_shortcode


		/**
		 * Currency conversion method
		 *
		 * @param     $convertion_value
		 * @param     $price
		 * @param     $convertfrom
		 * @param     $convertto
		 * @param int $decimalpoint
		 *
		 * @return  rating value
		 */
		public function cbxconvertcurrency_method_alphavantage( $convertion_value = 0, $price, $convertfrom, $convertto, $decimalpoint = 2 ) {
			return $this->cbxconvertcurrency_method_switcher( $convertion_value, $price, $convertfrom, $convertto, $decimalpoint );
		}

		/**
		 * Currency Rate api method switch based on setting
		 *
		 * @param     $convertion_value
		 * @param     $price
		 * @param     $convertfrom
		 * @param     $convertto
		 * @param int $decimalpoint
		 *
		 * @return  rating value
		 */
		public function cbxconvertcurrency_method_switcher( $convertion_value = 0, $price, $convertfrom, $convertto, $decimalpoint = 2 ) {

			$setting    = $this->settings_api;
			$api_source = $setting->get_option( 'api_source', 'cbcurrencyconverter_global_settings', 'alphavantage' );

			switch ( $api_source ) {
				case "alphavantage":
					return $this->alphavantage_api_method( $convertion_value, $price, $convertfrom, $convertto, $decimalpoint );
					break;
			}

			return $convertion_value;

		}//end cbxconvertcurrency_method_switcher


		/**
		 * alphavantage.con api method
		 *
		 * @param     $convertion_value
		 * @param     $price
		 * @param     $convertfrom
		 * @param     $convertto
		 * @param int $decimalpoint
		 *
		 * @return string
		 */
		public function alphavantage_api_method( $convertion_value = 0, $price, $convertfrom, $convertto, $decimalpoint = 2 ) {

			$setting = $this->settings_api;

			$cache         = intval( $setting->get_option( 'cbcurrencyconverter_ratecache', 'cbcurrencyconverter_global_settings', 1 ) ); //from version 2.7.1
			$cache_time_hr = intval( $setting->get_option( 'cbcurrencyconverter_cachetime', 'cbcurrencyconverter_global_settings', 2 ) ); //from version 2.7.1

			if ( $cache ) {
				// Get any existing copy of our transient data
				if ( false === ( $convertion_cache = get_transient( 'cbcurrencyconverter_alphavantage' ) ) ) {
					$convertion_cache                                    = array();
					$convertion_value                                    = $this->alphavantage_api_get( $convertfrom, $convertto );
					$convertion_cache[ $convertfrom . '-' . $convertto ] = $convertion_value;
					$convertion_cache                                    = maybe_serialize( $convertion_cache );

					//https://codex.wordpress.org/Transients_API
					set_transient( 'cbcurrencyconverter_alphavantage', $convertion_cache, $cache_time_hr * HOUR_IN_SECONDS );

					$convertion_value = $convertion_value * $price;
					$convertion_value = apply_filters( 'cbcurrencyconverter_rate_final', $convertion_value, $price, $convertfrom, $convertto, $decimalpoint );

					return number_format_i18n( $convertion_value, $decimalpoint );
				}

				$convertion_cache = maybe_unserialize( $convertion_cache );
				if ( isset( $convertion_cache[ $convertfrom . '-' . $convertto ] ) ) {
					$convertion_value = $convertion_cache[ $convertfrom . '-' . $convertto ];
				} else {
					$convertion_value                                    = $this->alphavantage_api_get( $convertfrom, $convertto );
					$convertion_cache[ $convertfrom . '-' . $convertto ] = $convertion_value;
					$convertion_cache                                    = maybe_serialize( $convertion_cache );

					//https://codex.wordpress.org/Transients_API
					set_transient( 'cbcurrencyconverter_alphavantage', $convertion_cache, $cache_time_hr * HOUR_IN_SECONDS );
				}
			} else {
				$convertion_value = $this->alphavantage_api_get( $convertfrom, $convertto );
			}


			//return number_format_i18n( ( $convertion_value * $price ), $decimalpoint );
			//return number_format_i18n( ( $convertion_value * $price ), $decimalpoint );

			$convertion_value = $convertion_value * $price;
			$convertion_value = apply_filters( 'cbcurrencyconverter_rate_final', $convertion_value, $price, $convertfrom, $convertto, $decimalpoint );

			return number_format_i18n( $convertion_value, $decimalpoint );
		}//end alphavantage_api_method

		/**
		 * api request to alphavantage.co
		 *
		 * @param $convertfrom
		 * @param $convertto
		 *
		 * @return int
		 */
		public function alphavantage_api_get( $convertfrom, $convertto ) {

			$setting = $this->settings_api;
			$api_key = $setting->get_option( 'apikey', 'cbcurrencyconverter_global_settings', '' );

			if ( $api_key == '' ) {
				return 0;
			}


			$url = 'https://www.alphavantage.co/query?function=CURRENCY_EXCHANGE_RATE&from_currency=' . urlencode( $convertfrom ) . '&to_currency=' . urlencode( $convertto ) . '&apikey=' . $api_key;
			$ch  = curl_init();

			curl_setopt( $ch, CURLOPT_URL, $url );
			curl_setopt( $ch, CURLOPT_RETURNTRANSFER, 1 );
			curl_setopt( $ch, CURLOPT_HEADER, 0 );
			curl_setopt( $ch, CURLOPT_SSL_VERIFYPEER, false );
			$body = curl_exec( $ch );

			curl_close( $ch );

			$result = json_decode( $body, true );
			$result = array_values( $result );

			if ( is_array( $result[0] ) ) {
				$result        = array_values( $result[0] );
				$from_currency = $result[0];
				$to_currency   = $result[1];
				$value         = $result[4];

				return $value;
			}

			return 0;
		}//end alphavantage_api_get


		/**
		 * Convert Currency ajax based main method
		 *
		 * @param     $price
		 * @param     $convertfrom
		 * @param     $convertto
		 * @param int $decimalpoint
		 *
		 * @return string
		 */
		public function getCurrencyRate( $price, $convertfrom, $convertto, $decimalpoint = 2 ) {
			$convertion_value = 0;

			return apply_filters( 'cbxcc_convertion_method', $convertion_value, $price, $convertfrom, $convertto, $decimalpoint );

			//return apply_filters('cbcurrencyconverter_rate_final', $convertion_value, $price, $convertfrom, $convertto, $decimalpoint );
			//return $convertion_value;
		}//end getCurrencyRate

		/**
		 * cbcurrencyconverter_ajax_cur_convert
		 */
		public function cbcurrencyconverter_ajax_cur_convert() {
			//security check
			if ( ! wp_verify_nonce( $_POST['cbcurrencyconverter_data']['nonce'], 'cbcurrencyconverter_nonce' ) ) {
				die( 'Security check' );
			}

			$setting       = $this->settings_api;
			$decimal_point = $setting->get_option( 'cbcurrencyconverter_decimalpoint', 'cbcurrencyconverter_global_settings', 2 );

			$cbcurrencyconverter_cur_data = $_POST['cbcurrencyconverter_data'];

			if ( $cbcurrencyconverter_cur_data['cbcurconvert_error'] == '' ) {
				$cbcurrencyconverter_result_cur = $this->getCurrencyRate( $cbcurrencyconverter_cur_data['cbcurconvert_amount'], $cbcurrencyconverter_cur_data['cbcurconvert_from'], $cbcurrencyconverter_cur_data['cbcurconvert_to'], $decimal_point );
			} else {
				$cbcurrencyconverter_result_cur = $cbcurrencyconverter_cur_data['cbcurconvert_error'];
			}
			echo( json_encode( $cbcurrencyconverter_result_cur ) );
			die();
		}//end cbcurrencyconverter_ajax_cur_convert

		/**
		 * Registering Widgets
		 */
		public function register_widgets() {
			register_widget( 'CBCurrencyConverterWidget' );
		}//end register_widgets

		/**
		 * Load Elementor Custom Icon
		 */
		function elementor_icon_loader() {
			wp_register_style( 'cbcurrencyconverter_elementor_icon', CBCURRENCYCONVERTER_ROOT_URL . 'widgets/elementor-elements/elementor-icon/icon.css', false, CBCURRENCYCONVERTER_VERSION );
			wp_enqueue_style( 'cbcurrencyconverter_elementor_icon' );
		}//end elementor_icon_loader


		/**
		 * Init elementor widget
		 *
		 * @throws Exception
		 */
		public function init_elementor_widgets() {
			//include file
			require_once plugin_dir_path( dirname( __FILE__ ) ) . 'widgets/elementor-elements/class-cbcurrencyconverter-elemwidget.php';

			//register elementor widget
			\Elementor\Plugin::instance()->widgets_manager->register_widget_type( new CBCurrencyConverterElemWidget\Widgets\CBCurrencyConverter_ElemWidget() );
		}//end widgets_registered

		/**
		 * Add new category to elementor
		 *
		 * @param $elements_manager
		 */
		public function add_elementor_widget_categories( $elements_manager ) {
			$elements_manager->add_category(
				'codeboxr',
				array(
					'title' => esc_html__( 'Codeboxr Widgets', 'cbcurrencyconverter' ),
					'icon'  => 'fa fa-plug',
				)
			);
		}//end add_elementor_widget_categories

		/**
		 * // Before VC Init
		 */
		public function vc_before_init_actions() {

			if ( ! class_exists( 'CBX_VCParam_DropDownMulti' ) ) {
				require_once CBCURRENCYCONVERTER_ROOT_PATH . 'widgets/vc-element/params/class-cbcurrencyconverter-vc-param-dropdown-multi.php';
			}

			if ( ! class_exists( 'CBCurrencyConverter_WPBWidget' ) ) {
				require_once CBCURRENCYCONVERTER_ROOT_PATH . 'widgets/vc-element/class-cbcurrencyconverter-wpbwidget.php';
			}


			new CBCurrencyConverter_WPBWidget();
		}// end method vc_before_init_actions
	}//end class CBCurrencyConverter_Public